@@ -345,6 +345,7 @@ def find_datetime_in_line(line):
     m = re.search(timestamp_pattern, line)
     return m[0]
 
+
 def preprocessing_output_directory(output_directory):
     """预处理输出目录
 
@@ -358,17 +359,46 @@ def preprocessing_output_directory(output_directory):
         if not os.path.exists(output_directory):
             os.makedirs(output_directory)
 
-        # file name like: 20210913175500-log.tar.gz
-        # max file number is 10 in the same time
-        # if files larger than 10, then delete the old ones beyond 10
-        # else do nothing
         files = os.listdir(output_directory)
-        files = sorted(files, reverse=True)
-        if len(files) > 10:
-            for file in files[10:]:
-                os.remove(f"{output_directory}/{file}")
+        # file name like: hostname-20210913175500.log.tar.gz
+        # sort by time
+        files.sort(key=lambda x: x.split('-')[1].split('.')[0], reverse=True)
 
-    except Exception as e:
-        print(f"Error: {e}")
+        for file in files:
+            file_full_path = os.path.join(output_directory, file)
+            if os.path.isfile(file_full_path):
+                os.remove(file_full_path)
+    except Exception as error:
+        print(error)
 
-    return output_directory
\ No newline at end of file
+
+def upload_to_obs(upload_file):
+    # check if {User}/obsutil/push.sh exists
+    try:
+        # ask if want to upload to obs
+        # print beautiful box around the tip in terminal
+        # the box length should auto adjust to the length of the tip
+
+
+        print("""
+        \033[1;31m
+        +-------------------------------------------------+
+            是否要将打包的日志文件上传到云盘？ (y/n) .
+        +-------------------------------------------------+
+        \033[0m
+        """.format(upload_file=upload_file))
+
+        print(f"是否要将 {upload_file} 上传到云盘? (y/n)")
+        if input() == 'y':
+            obsutil_push_script_path = os.path.join(os.path.expanduser('~'), 'obsutil', 'push.sh')
+
+            if not os.path.exists(obsutil_push_script_path):
+                print(f"{obsutil_push_script_path} 不存在, 请联系管理员安装")
+                return
+            # run {User}/obsutil/push.sh upload_file
+            os.system(f"{obsutil_push_script_path} {upload_file}")
+        else:
+            print(f"已选择跳过上传 {upload_file} 到云盘")
+
+    except Exception as error:
+        print(f"Error: {error}")
